(function (PLUGIN_ID) {
  const formEl = document.querySelector('.js-submit-settings');
  const cancelButtonEl = document.querySelector('.js-cancel-button');
  const apikeyEl = document.querySelector('.js-apikey');
  const modelEl = document.querySelector('.js-model');
  const roleEl = document.querySelector('.js-role');
  const replyFieldEl = document.querySelector('.js-reply-field');
  const spaceIdEl = document.querySelector('.js-space-id');
  const pdfFieldEl = document.querySelector('.js-pdf-field');

  if (!formEl || !cancelButtonEl || !apikeyEl || !modelEl || !roleEl || !replyFieldEl || !spaceIdEl|| !pdfFieldEl) {
    throw new Error('必要な要素が一つまたは複数足りません。');
  }

  const config = kintone.plugin.app.getConfig(PLUGIN_ID);
  if (config) {
    apikeyEl.value = config.apikey || '';
    if (config.model) {
      let modelOption = modelEl.querySelector(`option[value="${config.model}"]`);
      if (modelOption) {
        modelOption.selected = true;
      }
    }
    roleEl.value = config.role || '';
    replyFieldEl.value = config.replyField || '';
    spaceIdEl.value = config.spaceId || '';
    pdfFieldEl.value = config.pdfFileField || '';
  }

  formEl.addEventListener('submit', (e) => {
    e.preventDefault();
    const newConfig = {
      apikey: apikeyEl.value,
      model: modelEl.value,
      role: roleEl.value,
      replyField: replyFieldEl.value,
      spaceId: spaceIdEl.value,
      pdfFileField: pdfFieldEl.value
    };

    kintone.plugin.app.setConfig(newConfig, () => {
      alert('設定が保存されました。アプリを更新してください！');

      // 🔄 v1/responses 用プロキシ設定
      const url = 'https://api.openai.com/v1/responses';
      const method = "POST";
      const headers = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer ' + newConfig.apikey
      };
      const data = {
        model: newConfig.model,
        input: [
          {
            role: 'system',
            content: [{ type: 'input_text', text: 'あなたはPDFドキュメント解析の専門家AIです。・画像や表、図版を含むPDF全体を理解し、文字情報とビジュアル情報を組み合わせて処理します。  ・ユーザーからの指示（要約、抽出、分類など）に従い、必要な情報のみを過不足なく返してください。' }]
          },
          {
            role: 'user',
            content: [{ type: 'input_text', text:newConfig.role}]
          }
        ]
      };

      kintone.plugin.app.setProxyConfig(url, method, headers, data, () => {
        console.log('プロキシ設定も保存されました');
        window.location.href = '../../flow?app=' + kintone.app.getId();
      }, (error) => {
        console.error('プロキシ設定の保存中にエラーが発生しました:', error);
        alert('プロキシ設定の保存に失敗しました。もう一度お試しください。');
      });

    }, (error) => {
      console.error('設定の保存中にエラーが発生しました:', error);
      alert('設定の保存に失敗しました。もう一度お試しください。');
    });
  });

  cancelButtonEl.addEventListener('click', () => {
    window.location.href = '../../' + kintone.app.getId() + '/plugin/';
  });
})(kintone.$PLUGIN_ID);